==> tool-sql-2.6.0-pre-sources.jar: io/ciera/tool/sql/architecture/invocable/InvocableObjectSet.java <==
package io.ciera.tool.sql.architecture.invocable;


import io.ciera.runtime.summit.classes.IInstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.architecture.classes.AttributeDerivationSet;
import io.ciera.tool.sql.architecture.classes.OperationSet;
import io.ciera.tool.sql.architecture.component.FunctionSet;
import io.ciera.tool.sql.architecture.component.UtilityFunctionSet;
import io.ciera.tool.sql.architecture.expression.InvocationSet;
import io.ciera.tool.sql.architecture.interfaces.PortMessageSet;
import io.ciera.tool.sql.architecture.invocable.CodeBlockSet;
import io.ciera.tool.sql.architecture.invocable.FormalParameterSet;
import io.ciera.tool.sql.architecture.invocable.GenericInvocableSet;
import io.ciera.tool.sql.architecture.statemachine.EventSet;
import io.ciera.tool.sql.architecture.statemachine.StateSet;
import io.ciera.tool.sql.architecture.statemachine.StateTransitionSet;
import io.ciera.tool.sql.architecture.type.TypeReferenceSet;
import io.ciera.tool.sql.ooaofooa.body.BodySet;


public interface InvocableObjectSet extends IInstanceSet<InvocableObjectSet,InvocableObject> {

    // attributes
    public void setName( String m_name ) throws XtumlException;
    public void setAction_ID( UniqueId ref_Action_ID ) throws XtumlException;
    public void setType_package( String ref_type_package ) throws XtumlException;
    public void setOal( String m_oal ) throws XtumlException;
    public void setParent_package( String m_parent_package ) throws XtumlException;
    public void setType_reference_name( String ref_type_reference_name ) throws XtumlException;
    public void setParent_name( String m_parent_name ) throws XtumlException;
    public void setType_name( String ref_type_name ) throws XtumlException;


    // selections
    public CodeBlockSet R4000_has_CodeBlock() throws XtumlException;
    public AttributeDerivationSet R427_is_a_AttributeDerivation() throws XtumlException;
    public EventSet R427_is_a_Event() throws XtumlException;
    public FunctionSet R427_is_a_Function() throws XtumlException;
    public GenericInvocableSet R427_is_a_GenericInvocable() throws XtumlException;
    public OperationSet R427_is_a_Operation() throws XtumlException;
    public PortMessageSet R427_is_a_PortMessage() throws XtumlException;
    public StateSet R427_is_a_State() throws XtumlException;
    public StateTransitionSet R427_is_a_StateTransition() throws XtumlException;
    public UtilityFunctionSet R427_is_a_UtilityFunction() throws XtumlException;
    public TypeReferenceSet R428_return_value_is_typed_by_TypeReference() throws XtumlException;
    public FormalParameterSet R429_declares_signature_with_FormalParameter() throws XtumlException;
    public BodySet R432_transforms_actions_from_Body() throws XtumlException;
    public InvocationSet R792_invoked_through_Invocation() throws XtumlException;


}

==> tool-sql-2.7.0-sources.jar: io/ciera/tool/sql/architecture/invocable/InvocableObjectSet.java <==
package io.ciera.tool.sql.architecture.invocable;


import io.ciera.runtime.summit.classes.IInstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.tool.sql.architecture.classes.AttributeDerivationSet;
import io.ciera.tool.sql.architecture.classes.OperationSet;
import io.ciera.tool.sql.architecture.component.FunctionSet;
import io.ciera.tool.sql.architecture.component.UtilityFunctionSet;
import io.ciera.tool.sql.architecture.expression.InvocationSet;
import io.ciera.tool.sql.architecture.interfaces.PortMessageSet;
import io.ciera.tool.sql.architecture.invocable.CodeBlockSet;
import io.ciera.tool.sql.architecture.invocable.FormalParameterSet;
import io.ciera.tool.sql.architecture.invocable.GenericInvocableSet;
import io.ciera.tool.sql.architecture.statemachine.EventSet;
import io.ciera.tool.sql.architecture.statemachine.StateSet;
import io.ciera.tool.sql.architecture.statemachine.StateTransitionSet;
import io.ciera.tool.sql.architecture.type.TypeReferenceSet;
import io.ciera.tool.sql.ooaofooa.body.BodySet;


public interface InvocableObjectSet extends IInstanceSet<InvocableObjectSet,InvocableObject> {

    // attributes
    public void setType_name( String ref_type_name ) throws XtumlException;
    public void setName( String m_name ) throws XtumlException;
    public void setType_package( String ref_type_package ) throws XtumlException;
    public void setParent_package( String m_parent_package ) throws XtumlException;
    public void setType_reference_name( String ref_type_reference_name ) throws XtumlException;
    public void setActions( String m_actions ) throws XtumlException;
    public void setParent_name( String m_parent_name ) throws XtumlException;


    // selections
    public CodeBlockSet R4000_has_CodeBlock() throws XtumlException;
    public AttributeDerivationSet R427_is_a_AttributeDerivation() throws XtumlException;
    public EventSet R427_is_a_Event() throws XtumlException;
    public FunctionSet R427_is_a_Function() throws XtumlException;
    public GenericInvocableSet R427_is_a_GenericInvocable() throws XtumlException;
    public OperationSet R427_is_a_Operation() throws XtumlException;
    public PortMessageSet R427_is_a_PortMessage() throws XtumlException;
    public StateSet R427_is_a_State() throws XtumlException;
    public StateTransitionSet R427_is_a_StateTransition() throws XtumlException;
    public UtilityFunctionSet R427_is_a_UtilityFunction() throws XtumlException;
    public TypeReferenceSet R428_return_value_is_typed_by_TypeReference() throws XtumlException;
    public FormalParameterSet R429_declares_signature_with_FormalParameter() throws XtumlException;
    public BodySet R432_Body() throws XtumlException;
    public InvocationSet R792_invoked_through_Invocation() throws XtumlException;


}
